@@ -9,6 +9,8 @@ https://gist.github.com/561347/9846ebf8d0a69b06681da9255ffe3d3f59ec2c97
 Used and modified with permission.
 """
 
+import sys
+
 import agate
 
 from csvkit.cli import CSVKitUtility
@@ -22,9 +24,9 @@ class CSVCut(CSVKitUtility):
         self.argparser.add_argument('-n', '--names', dest='names_only', action='store_true',
                                     help='Display column names and indices from the input CSV and exit.')
         self.argparser.add_argument('-c', '--columns', dest='columns',
-                                    help='A comma separated list of column indices or names to be extracted. Defaults to all columns.')
+                                    help='A comma separated list of column indices, names or ranges to be extracted, e.g. "1,id,3-5". Defaults to all columns.')
         self.argparser.add_argument('-C', '--not-columns', dest='not_columns',
-                                    help='A comma separated list of column indices or names to be excluded. Defaults to no columns.')
+                                    help='A comma separated list of column indices, names or ranges to be excluded, e.g. "1,id,3-5". Defaults to no columns.')
         self.argparser.add_argument('-x', '--delete-empty-rows', dest='delete_empty', action='store_true',
                                     help='After cutting, delete rows which are completely empty.')
 
@@ -33,6 +35,9 @@ class CSVCut(CSVKitUtility):
             self.print_column_names()
             return
 
+        if self.additional_input_expected():
+            sys.stderr.write('No input file or piped data provided. Waiting for standard input:\n')
+
         rows, column_names, column_ids = self.get_rows_and_column_names_and_column_ids(**self.reader_kwargs)
 
         output = agate.csv.writer(self.output_file, **self.writer_kwargs)
