@@ -71,7 +71,7 @@ class CSVStat(CSVKitUtility):
         self.argparser.add_argument('-n', '--names', dest='names_only', action='store_true',
                                     help='Display column names and indices from the input CSV and exit.')
         self.argparser.add_argument('-c', '--columns', dest='columns',
-                                    help='A comma separated list of column indices or names to be examined. Defaults to all columns.')
+                                    help='A comma separated list of column indices, names or ranges to be examined, e.g. "1,id,3-5". Defaults to all columns.')
         self.argparser.add_argument('--type', dest='type_only', action='store_true',
                                     help='Only output data type.')
         self.argparser.add_argument('--nulls', dest='nulls_only', action='store_true',
@@ -106,6 +106,9 @@ class CSVStat(CSVKitUtility):
             self.print_column_names()
             return
 
+        if self.additional_input_expected():
+            self.argparser.error('You must provide an input file or piped data.')
+
         operations = [op for op in OPERATIONS.keys() if getattr(self.args, op + '_only')]
 
         if len(operations) > 1:
@@ -222,7 +225,7 @@ class CSVStat(CSVKitUtility):
                         v = table.aggregate(op(column_id))
 
                         if isinstance(v, Decimal):
-                            v = format_decimal(v)
+                            v = format_decimal(v, locale=agate.config.get_option('default_locale'))
 
                         stats[op_name] = v
                 except:
@@ -266,7 +269,7 @@ class CSVStat(CSVKitUtility):
                             v = row[column_name]
 
                             if isinstance(v, Decimal):
-                                v = format_decimal(v)
+                                v = format_decimal(v, locale=agate.config.get_option('default_locale'))
                         else:
                             v = six.text_type(row[column_name])
 
